GuestContext

Struct GuestContext 

pub struct GuestContext { /* private fields */ }
The guest-visible architectural state of an x86 vCPU.

Register values can be modified without affecting the host CPU. The caller is responsible for initializing them for the guest’s execution mode.

Implementations

Source

impl GuestContext

pub fn new(regs: VcpuRegs, sregs: VcpuSregs, msrs: VcpuMsrs) -> Self

Creates a guest vCPU context from initialized register state.

pub fn regs(&self) -> &VcpuRegs

Returns the guest’s general-purpose registers, instruction pointer, and flags.

pub fn regs_mut(&mut self) -> &mut VcpuRegs

Returns a mutable reference to the guest’s general-purpose registers, instruction pointer, and flags.

pub fn sregs(&self) -> &VcpuSregs

Returns the guest’s special registers.

pub fn sregs_mut(&mut self) -> &mut VcpuSregs

Returns a mutable reference to the guest’s special registers.

pub fn msrs(&self) -> &VcpuMsrs

Returns the guest’s MSRs that are not part of VcpuSregs.

pub fn msrs_mut(&mut self) -> &mut VcpuMsrs

Returns a mutable reference to the guest’s MSRs that are not part of VcpuSregs.