pub struct GuestContext { /* private fields */ }Expand description
The guest-visible architectural state of an x86 vCPU.
Register values can be modified without affecting the host CPU. The caller is responsible for initializing them for the guest’s execution mode.
Implementations
Sourceimpl GuestContext
impl GuestContext
Sourcepub fn new(regs: VcpuRegs, sregs: VcpuSregs, msrs: VcpuMsrs) -> Self
pub fn new(regs: VcpuRegs, sregs: VcpuSregs, msrs: VcpuMsrs) -> Self
Creates a guest vCPU context from initialized register state.
Sourcepub fn regs(&self) -> &VcpuRegs
pub fn regs(&self) -> &VcpuRegs
Returns the guest’s general-purpose registers, instruction pointer, and flags.
Sourcepub fn regs_mut(&mut self) -> &mut VcpuRegs
pub fn regs_mut(&mut self) -> &mut VcpuRegs
Returns a mutable reference to the guest’s general-purpose registers, instruction pointer, and flags.